@@ -9,9 +9,9 @@
 
 #include "button.h"
 
-#include <kconfig.h>
-#include <ksharedconfig.h>
-#include <kconfiggroup.h>
+#include <KConfig>
+#include <KSharedConfig>
+#include <KConfigGroup>
 
 #include <QKeySequence>
 
